@@ -1,4 +1,5 @@
 from typing import Any, Iterator, TypeVar
+from pytorch_lightning.overrides.distributed import IndexBatchSamplerWrapper
 from torch.utils.data import DataLoader as TorchDataLoader
 from torch.utils.data import Dataset, TensorDataset
 from torch.utils.data.sampler import SequentialSampler
@@ -49,6 +50,7 @@ class DataLoader(TorchDataLoader[T_co]):
             kwargs.setdefault("collate_fn", collate_tuple)
 
         super().__init__(dataset, **kwargs)  # type: ignore
+
         self.custom_batching = self.num_workers == 0 and (
             isinstance(self.batch_sampler, RangeBatchSampler)
             or (
@@ -56,6 +58,10 @@ class DataLoader(TorchDataLoader[T_co]):
                 and hasattr(self.batch_sampler, "sampler")
                 and isinstance(self.batch_sampler.sampler, RangeBatchSampler)
             )
+            or (
+                isinstance(self.batch_sampler, IndexBatchSamplerWrapper)
+                and isinstance(self.batch_sampler._sampler, RangeBatchSampler)  # type: ignore
+            )
         )
 
     def __iter__(self) -> Iterator[Any]:  # pylint: disable=inconsistent-return-statements
