@@ -1,9 +1,11 @@
 from .base import BaseEstimator
+from .configurable import ConfigurableBaseEstimator
 from .exception import NotFittedError
 from .mixins import PredictorMixin, TransformerMixin
 
 __all__ = [
     "BaseEstimator",
+    "ConfigurableBaseEstimator",
     "NotFittedError",
     "PredictorMixin",
     "TransformerMixin",
